@@ -78,7 +78,6 @@ class Database:
                 df = df.set_index(keys='datetime')
                 df = df.sort_index()
 
-
                 if price_adj == True:
 
                     qfq_df = qfq_df[qfq_df['date'] > 20100000]
@@ -87,13 +86,14 @@ class Database:
                     qfq_df['date'] = qfq_df['date'].astype(str)
                     first_date = qfq_df.loc[qfq_df.index[0], 'date']
                     min_date_of_ohlc_df = df['date'].min()
-                    if first_date > min_date_of_ohlc_df:
+                    if int(first_date) > int(min_date_of_ohlc_df):
                         first_date = min_date_of_ohlc_df
 
                     last_date = str(max([int(qfq_df.loc[qfq_df.index[-1], 'date']), int(df.loc[df.index[-1], 'date'])]))
                     qfq_df['date'] = pd.to_datetime(qfq_df['date'], format='%Y-%m-%d')
                     qfq_df = qfq_df.set_index(keys='date')
                     t_index = pd.DatetimeIndex(pd.date_range(start=first_date, end=last_date, freq='1D'))
+
                     qfq_df = qfq_df.reindex(t_index)
                     qfq_df = qfq_df.fillna(method='bfill')
                     qfq_df = qfq_df.fillna(method='ffill')
@@ -272,6 +272,7 @@ class Database:
                     if len(sub_df_list) > 0:
                         df = pd.concat(sub_df_list)
                         df = df.reset_index(drop=True)
+                        print(df)
                         temp_date_list = list(df['date'].unique())
                         temp_date_list.sort()
 
@@ -1107,8 +1108,8 @@ class Database:
             df['market_capital'] = df['market_capital'].astype('int64')
             df['is_stop_trading'] = df['is_stop_trading'].map({'True': True, 'False': False})
 
-            df = df[['code','stock_name','price','PE','EPS','dividend','volume','turnover','share_issued','lot_size','market_capital','ipo_date','year_end_date', 'is_stop_trading']]
-
+            df = df[['code','stock_name','price','PE','EPS','dividend','volume','turnover','share_issued','lot_size','market_capital','ipo_date','year_end_date', 'is_stop_trading','Category']]
+            df = df.rename(columns={'Category':'category'})
             return df
 
     def get_hk_ipo_hist(self):
